summaryrefslogtreecommitdiffstats
path: root/tdecore
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore')
-rw-r--r--tdecore/CMakeLists.txt10
-rw-r--r--tdecore/MAINTAINERS8
-rw-r--r--tdecore/Makefile.am10
-rw-r--r--tdecore/configure.in.in2
-rw-r--r--tdecore/kapplication_win.cpp2
-rw-r--r--tdecore/kcatalogue.cpp2
-rw-r--r--tdecore/kdebug.cpp2
-rw-r--r--tdecore/kdesktopfile.cpp2
-rw-r--r--tdecore/kiconloader.cpp2
-rw-r--r--tdecore/kicontheme.cpp2
-rw-r--r--tdecore/kinstance.cpp2
-rw-r--r--tdecore/klibloader.cpp2
-rw-r--r--tdecore/kmountpoint.cpp2
-rw-r--r--tdecore/knotifyclient.cpp2
-rw-r--r--tdecore/kpalette.cpp2
-rw-r--r--tdecore/kprotocolinfo_tdecore.cpp2
-rw-r--r--tdecore/kprotocolinfofactory.cpp2
-rw-r--r--tdecore/kpty.cpp2
-rw-r--r--tdecore/krfcdate.cpp10
-rw-r--r--tdecore/ksavefile.cpp2
-rw-r--r--tdecore/ksimpleconfig.cpp2
-rw-r--r--tdecore/kstddirs.h6
-rw-r--r--tdecore/ktempdir.cpp2
-rw-r--r--tdecore/network/kresolverstandardworkers.cpp2
-rw-r--r--tdecore/tde-config.cpp.cmake2
-rw-r--r--tdecore/tde-config.cpp.in2
-rw-r--r--tdecore/tdeaboutdata.cpp2
-rw-r--r--tdecore/tdeapplication.cpp4
-rw-r--r--tdecore/tdeconfig.cpp2
-rw-r--r--tdecore/tdeconfig_compiler/example/autoexample.cpp2
-rw-r--r--tdecore/tdeconfig_compiler/example/example.cpp2
-rw-r--r--tdecore/tdeconfig_compiler/tdeconfig_compiler.cpp2
-rw-r--r--tdecore/tdeconfigbackend.cpp2
-rw-r--r--tdecore/tdeconfigbase.cpp2
-rw-r--r--tdecore/tdeconfigskeleton.cpp2
-rw-r--r--tdecore/tdeglobal.cpp2
-rw-r--r--tdecore/tdeglobalaccel.cpp (renamed from tdecore/kglobalaccel.cpp)12
-rw-r--r--tdecore/tdeglobalaccel.h (renamed from tdecore/kglobalaccel.h)6
-rw-r--r--tdecore/tdeglobalaccel_emb.h (renamed from tdecore/kglobalaccel_emb.h)6
-rw-r--r--tdecore/tdeglobalaccel_mac.h (renamed from tdecore/kglobalaccel_mac.h)6
-rw-r--r--tdecore/tdeglobalaccel_win.cpp (renamed from tdecore/kglobalaccel_win.cpp)6
-rw-r--r--tdecore/tdeglobalaccel_win.h (renamed from tdecore/kglobalaccel_win.h)6
-rw-r--r--tdecore/tdeglobalaccel_x11.cpp (renamed from tdecore/kglobalaccel_x11.cpp)6
-rw-r--r--tdecore/tdeglobalaccel_x11.h (renamed from tdecore/kglobalaccel_x11.h)6
-rw-r--r--tdecore/tdeglobalsettings.cpp2
-rw-r--r--tdecore/tdehw/networkbackends/network-manager/network-manager.cpp59
-rw-r--r--tdecore/tdehw/networkbackends/network-manager/network-manager.h4
-rw-r--r--tdecore/tdehw/tdehardwaredevices.cpp2
-rw-r--r--tdecore/tdehw/tderootsystemdevice.cpp2
-rw-r--r--tdecore/tdehw/tdestoragedevice.cpp2
-rw-r--r--tdecore/tdelocale.cpp2
-rw-r--r--tdecore/tdeprocess.cpp2
-rw-r--r--tdecore/tdeshortcutlist.cpp2
-rw-r--r--tdecore/tdestandarddirs.cpp (renamed from tdecore/kstandarddirs.cpp)8
-rw-r--r--tdecore/tdestandarddirs.h (renamed from tdecore/kstandarddirs.h)46
-rw-r--r--tdecore/tdesycoca.cpp2
-rw-r--r--tdecore/tdetempfile.cpp2
-rw-r--r--tdecore/tdeuniqueapplication.cpp2
-rw-r--r--tdecore/tests/CMakeLists.txt42
-rw-r--r--tdecore/tests/Makefile.am4
-rw-r--r--tdecore/tests/krfcdatetest.cpp6
-rw-r--r--tdecore/tests/ktempfiletest.cpp2
-rw-r--r--tdecore/tests/tdestandarddirstest.cpp (renamed from tdecore/tests/kstddirstest.cpp)2
63 files changed, 192 insertions, 163 deletions
diff --git a/tdecore/CMakeLists.txt b/tdecore/CMakeLists.txt
index 2b6d4c67e..8528c4c01 100644
--- a/tdecore/CMakeLists.txt
+++ b/tdecore/CMakeLists.txt
@@ -56,9 +56,9 @@ install( FILES
kcharsets.h tdeversion.h kpty.h tdeprocess.h tdeprocctrl.h
tdelocale.h kicontheme.h kiconloader.h kdebug.h twinmodule.h
twin.h krootprop.h tdeshortcut.h kkeynative.h tdeaccel.h
- kglobalaccel.h tdestdaccel.h tdeshortcutlist.h kcatalogue.h
- kregexp.h kcompletion.h kstringhandler.h kstddirs.h
- kstandarddirs.h tdeglobal.h tdeglobalsettings.h ksharedptr.h
+ tdeglobalaccel.h tdestdaccel.h tdeshortcutlist.h kcatalogue.h
+ kregexp.h kcompletion.h kstringhandler.h
+ tdestandarddirs.h tdeglobal.h tdeglobalsettings.h ksharedptr.h
kallocator.h kvmallocator.h tdecrash.h krfcdate.h kinstance.h
kpalette.h kipc.h klibloader.h tdetempfile.h ksavefile.h
krandomsequence.h knotifyclient.h kiconeffect.h kaudioplayer.h
@@ -107,13 +107,13 @@ set( target tdecore )
set( ${target}_SRCS
libintl.cpp tdeapplication.cpp kdebug.cpp netwm.cpp
tdeconfigbase.cpp tdeconfig.cpp ksimpleconfig.cpp tdeconfigbackend.cpp
- kmanagerselection.cpp kdesktopfile.cpp kstandarddirs.cpp
+ kmanagerselection.cpp kdesktopfile.cpp tdestandarddirs.cpp
ksock.cpp kpty.cpp tdeprocess.cpp tdeprocctrl.cpp tdelocale.cpp
krfcdate.cpp kiconeffect.cpp kicontheme.cpp kiconloader.cpp
twin.cpp twinmodule.cpp krootprop.cpp kcharsets.cpp
kckey.cpp tdeshortcut.cpp kkeynative_x11.cpp kkeyserver_x11.cpp
tdeaccelaction.cpp tdeshortcutmenu.cpp tdeaccelbase.cpp tdeaccel.cpp
- kglobalaccel_x11.cpp kglobalaccel.cpp tdestdaccel.cpp tdeshortcutlist.cpp
+ tdeglobalaccel_x11.cpp tdeglobalaccel.cpp tdestdaccel.cpp tdeshortcutlist.cpp
tdecrash.cpp kurl.cpp kregexp.cpp tdeglobal.cpp tdeglobalsettings.cpp
kallocator.cpp kvmallocator.cpp kmimesourcefactory.cpp
kinstance.cpp kpalette.cpp kipc.cpp klibloader.cpp tdetempfile.cpp
diff --git a/tdecore/MAINTAINERS b/tdecore/MAINTAINERS
index 39b3a1424..fef36b95d 100644
--- a/tdecore/MAINTAINERS
+++ b/tdecore/MAINTAINERS
@@ -28,8 +28,8 @@ kdcoppropertyproxy.cpp
kdebug.cpp Stephan Kulow <[email protected]>
kdesktopfile.cpp
tdeglobal.cpp Stephan Kulow <[email protected]>
-kglobalaccel.cpp Ellis Whitehead <[email protected]>
-kglobalaccel_x11.cpp Ellis Whitehead <[email protected]>
+tdeglobalaccel.cpp Ellis Whitehead <[email protected]>
+tdeglobalaccel_x11.cpp Ellis Whitehead <[email protected]>
tdeglobalsettings.cpp David Faure <[email protected]>
kiconeffect.cpp
kiconloader.cpp
@@ -59,7 +59,7 @@ ksavefile.cpp Waldo Bastian <[email protected]>
tdeshortcut.cpp Ellis Whitehead <[email protected]>
ksimpleconfig.cpp Waldo Bastian <[email protected]>
ksocks.cpp
-kstandarddirs.cpp Waldo Bastian <[email protected]>
+tdestandarddirs.cpp Waldo Bastian <[email protected]>
tdestartupinfo.cpp Lubos Lunak <[email protected]>
kstaticdeleter.cpp Stephan Kulow <[email protected]>
tdestdaccel.cpp Ellis Whitehead <[email protected]>
@@ -98,7 +98,7 @@ tdeconfigdialogmanager.cpp
tdeconfigskeleton.cpp
kdebugdcopiface.cpp Andreas Beckermann ([email protected]) (copyright)
tdeversion.cpp
-kglobalaccel_win.cpp Ellis Whitehead <[email protected]> (copyright)
+tdeglobalaccel_win.cpp Ellis Whitehead <[email protected]> (copyright)
kkeyserver_x11.cpp
klockfile.cpp Waldo Bastian <[email protected]> (copyright)
kmacroexpander.cpp
diff --git a/tdecore/Makefile.am b/tdecore/Makefile.am
index 924362b3f..b3772b1c7 100644
--- a/tdecore/Makefile.am
+++ b/tdecore/Makefile.am
@@ -43,9 +43,9 @@ include_HEADERS = tdeconfig.h tdeconfigskeleton.h \
tdeuniqueapplication.h kcharsets.h tdeversion.h kpty.h tdeprocess.h \
tdeprocctrl.h tdelocale.h kicontheme.h kiconloader.h kdebug.h \
twinmodule.h twin.h krootprop.h tdeshortcut.h kkeynative.h tdeaccel.h \
- kglobalaccel.h tdestdaccel.h tdeshortcutlist.h kcatalogue.h \
+ tdeglobalaccel.h tdestdaccel.h tdeshortcutlist.h kcatalogue.h \
kregexp.h kcompletion.h kstringhandler.h \
- kstddirs.h kstandarddirs.h tdeglobal.h tdeglobalsettings.h ksharedptr.h \
+ tdestandarddirs.h tdeglobal.h tdeglobalsettings.h ksharedptr.h \
kallocator.h kvmallocator.h tdecrash.h krfcdate.h \
kinstance.h kpalette.h kipc.h klibloader.h tdetempfile.h ksavefile.h \
krandomsequence.h knotifyclient.h kiconeffect.h \
@@ -83,7 +83,7 @@ libtdefakes_pic.a: libtdefakes.la
noinst_HEADERS = tdeaccelaction.h tdeaccelbase.h tdeaccelprivate.h kckey.h \
kcompletion_private.h netwm_p.h \
- kglobalaccel_x11.h kglobalaccel_win.h kkeyserver_x11.h kkeyserver.h \
+ tdeglobalaccel_x11.h tdeglobalaccel_win.h kkeyserver_x11.h kkeyserver.h \
kregpriv.h tdeshortcutmenu.h tdesycocadict.h tdesycocafactory.h netsupp.h \
kcheckaccelerators.h kcalendarsystemgregorian.h \
kcalendarsystemhijri.h kcalendarsystemhebrew.h kcalendarsystemjalali.h \
@@ -92,12 +92,12 @@ noinst_HEADERS = tdeaccelaction.h tdeaccelbase.h tdeaccelprivate.h kckey.h \
libtdecore_la_SOURCES = libintl.cpp tdeapplication.cpp \
kdebug.cpp netwm.cpp tdeconfigbase.cpp tdeconfig.cpp ksimpleconfig.cpp \
tdeconfigbackend.cpp kmanagerselection.cpp kdesktopfile.cpp \
- kstandarddirs.cpp ksock.cpp kpty.cpp tdeprocess.cpp tdeprocctrl.cpp \
+ tdestandarddirs.cpp ksock.cpp kpty.cpp tdeprocess.cpp tdeprocctrl.cpp \
tdelocale.cpp krfcdate.cpp kiconeffect.cpp kicontheme.cpp \
kiconloader.cpp twin.cpp twinmodule.cpp krootprop.cpp kcharsets.cpp \
kckey.cpp tdeshortcut.cpp kkeynative_x11.cpp kkeyserver_x11.cpp \
tdeaccelaction.cpp tdeshortcutmenu.cpp tdeaccelbase.cpp tdeaccel.cpp \
- kglobalaccel_x11.cpp kglobalaccel.cpp tdestdaccel.cpp tdeshortcutlist.cpp \
+ tdeglobalaccel_x11.cpp tdeglobalaccel.cpp tdestdaccel.cpp tdeshortcutlist.cpp \
tdecrash.cpp kurl.cpp kregexp.cpp tdeglobal.cpp tdeglobalsettings.cpp \
kallocator.cpp kvmallocator.cpp kmimesourcefactory.cpp \
kinstance.cpp kpalette.cpp kipc.cpp klibloader.cpp tdetempfile.cpp \
diff --git a/tdecore/configure.in.in b/tdecore/configure.in.in
index 7ecda35e7..8dde23486 100644
--- a/tdecore/configure.in.in
+++ b/tdecore/configure.in.in
@@ -1,4 +1,4 @@
-dnl Compile in the exec prefix to help kstddirs in finding dynamic libs
+dnl Compile in the exec prefix to help tdestandarddirs in finding dynamic libs
AC_DEFINE_UNQUOTED(__KDE_EXECPREFIX, "$exec_prefix", [execprefix or NONE if not set, for libloading])
dnl Compile in kde_bindir to safely find tdesu_stub.
diff --git a/tdecore/kapplication_win.cpp b/tdecore/kapplication_win.cpp
index 2e9a8a0ba..0da2ced26 100644
--- a/tdecore/kapplication_win.cpp
+++ b/tdecore/kapplication_win.cpp
@@ -18,7 +18,7 @@
*/
#include <tdeapplication.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdelocale.h>
#include <kurl.h>
diff --git a/tdecore/kcatalogue.cpp b/tdecore/kcatalogue.cpp
index 24d0193b2..d91338d1f 100644
--- a/tdecore/kcatalogue.cpp
+++ b/tdecore/kcatalogue.cpp
@@ -24,7 +24,7 @@
#include <kdebug.h>
#include "kcatalogue.h"
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
char *k_nl_find_msg(struct kde_loaded_l10nfile *domain_file,
const char *msgid);
diff --git a/tdecore/kdebug.cpp b/tdecore/kdebug.cpp
index 368aaef5d..46dac11d8 100644
--- a/tdecore/kdebug.cpp
+++ b/tdecore/kdebug.cpp
@@ -29,7 +29,7 @@
#include "tdeapplication.h"
#include "tdeglobal.h"
#include "kinstance.h"
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
#include <tqmessagebox.h>
#include <tdelocale.h>
diff --git a/tdecore/kdesktopfile.cpp b/tdecore/kdesktopfile.cpp
index 3e262be3a..27b25858b 100644
--- a/tdecore/kdesktopfile.cpp
+++ b/tdecore/kdesktopfile.cpp
@@ -32,7 +32,7 @@
#include "kurl.h"
#include "tdeconfigbackend.h"
#include "tdeapplication.h"
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
#include "kmountpoint.h"
#include "kcatalogue.h"
#include "tdelocale.h"
diff --git a/tdecore/kiconloader.cpp b/tdecore/kiconloader.cpp
index db98fbffd..8c56990d8 100644
--- a/tdecore/kiconloader.cpp
+++ b/tdecore/kiconloader.cpp
@@ -29,7 +29,7 @@
#include <tdeapplication.h>
#include <kipc.h>
#include <kdebug.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdeglobal.h>
#include <tdeconfig.h>
#include <ksimpleconfig.h>
diff --git a/tdecore/kicontheme.cpp b/tdecore/kicontheme.cpp
index dd2cd2944..f0793f2c1 100644
--- a/tdecore/kicontheme.cpp
+++ b/tdecore/kicontheme.cpp
@@ -29,7 +29,7 @@
#include <tqdir.h>
#include <kdebug.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdeglobal.h>
#include <tdeconfig.h>
#include <ksimpleconfig.h>
diff --git a/tdecore/kinstance.cpp b/tdecore/kinstance.cpp
index 8ae747948..c5fe83ccc 100644
--- a/tdecore/kinstance.cpp
+++ b/tdecore/kinstance.cpp
@@ -31,7 +31,7 @@
#include "tdenetworkconnections.h"
#endif
#include "tdeaboutdata.h"
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
#include "kdebug.h"
#include "tdeglobal.h"
#include "kmimesourcefactory.h"
diff --git a/tdecore/klibloader.cpp b/tdecore/klibloader.cpp
index 2d33aa80b..ca77c5f8c 100644
--- a/tdecore/klibloader.cpp
+++ b/tdecore/klibloader.cpp
@@ -27,7 +27,7 @@
#include "tdeapplication.h"
#include "klibloader.h"
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
#include "kdebug.h"
#include "tdelocale.h"
diff --git a/tdecore/kmountpoint.cpp b/tdecore/kmountpoint.cpp
index 0828911ef..e5a67e0f3 100644
--- a/tdecore/kmountpoint.cpp
+++ b/tdecore/kmountpoint.cpp
@@ -25,7 +25,7 @@
#include <tqfile.h>
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
#include "kmountpoint.h"
diff --git a/tdecore/knotifyclient.cpp b/tdecore/knotifyclient.cpp
index eaac81754..7d4c675d7 100644
--- a/tdecore/knotifyclient.cpp
+++ b/tdecore/knotifyclient.cpp
@@ -24,7 +24,7 @@
#include <tqptrstack.h>
#include <tdeapplication.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdeapplication.h>
#include <tdeconfig.h>
#include <dcopclient.h>
diff --git a/tdecore/kpalette.cpp b/tdecore/kpalette.cpp
index 7335e8e14..66f235e5e 100644
--- a/tdecore/kpalette.cpp
+++ b/tdecore/kpalette.cpp
@@ -23,7 +23,7 @@
#include <tqfile.h>
#include <tqtextstream.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdeglobal.h>
#include <ksavefile.h>
#include <kstringhandler.h>
diff --git a/tdecore/kprotocolinfo_tdecore.cpp b/tdecore/kprotocolinfo_tdecore.cpp
index af48a5386..3d08cccd5 100644
--- a/tdecore/kprotocolinfo_tdecore.cpp
+++ b/tdecore/kprotocolinfo_tdecore.cpp
@@ -25,7 +25,7 @@
#include "kprotocolinfo.h"
#include "kprotocolinfofactory.h"
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdeglobal.h>
#include <tdeapplication.h>
#include <kdebug.h>
diff --git a/tdecore/kprotocolinfofactory.cpp b/tdecore/kprotocolinfofactory.cpp
index 115a44f25..19efdc465 100644
--- a/tdecore/kprotocolinfofactory.cpp
+++ b/tdecore/kprotocolinfofactory.cpp
@@ -17,7 +17,7 @@
Boston, MA 02110-1301, USA.
*/
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdeglobal.h>
#include <tdeapplication.h>
#include <kdebug.h>
diff --git a/tdecore/kpty.cpp b/tdecore/kpty.cpp
index 86f5bfefa..d801b7c9a 100644
--- a/tdecore/kpty.cpp
+++ b/tdecore/kpty.cpp
@@ -121,7 +121,7 @@ extern "C" {
#endif
#include <kdebug.h>
-#include <kstandarddirs.h> // locate
+#include <tdestandarddirs.h> // locate
#ifndef CINTR
#define CINTR 0x03
diff --git a/tdecore/krfcdate.cpp b/tdecore/krfcdate.cpp
index 327736b40..08691fd15 100644
--- a/tdecore/krfcdate.cpp
+++ b/tdecore/krfcdate.cpp
@@ -431,12 +431,16 @@ KRFCDate::parseDateISO8601( const TQString& input_ )
l = TQStringList::split(':', timeString);
- if (l.size() < 3)
+ // If the 'T' separator was included, there must at least
+ // be the hour, if not then it is invalid.
+ if (l.size() < 1)
return 0;
hour = l[0].toUInt();
- min = l[1].toUInt();
- sec = l[2].toUInt();
+
+ // Minutes and seconds can be omitted.
+ min = (l.size() >= 2) ? l[1].toUInt() : 0;
+ sec = (l.size() >= 3) ? l[2].toUInt() : 0;
time_t result = ymdhms_to_seconds(year, month, mday, hour, min, sec);
diff --git a/tdecore/ksavefile.cpp b/tdecore/ksavefile.cpp
index d9b8867af..9bf409c1c 100644
--- a/tdecore/ksavefile.cpp
+++ b/tdecore/ksavefile.cpp
@@ -38,7 +38,7 @@
#include <kde_file.h>
#include "tdeapplication.h"
#include "ksavefile.h"
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
KSaveFile::KSaveFile(const TQString &filename, int mode)
: mTempFile(true)
diff --git a/tdecore/ksimpleconfig.cpp b/tdecore/ksimpleconfig.cpp
index dc359f17e..26a201f85 100644
--- a/tdecore/ksimpleconfig.cpp
+++ b/tdecore/ksimpleconfig.cpp
@@ -32,7 +32,7 @@
#include <tqdir.h>
#include "tdeglobal.h"
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
#include "tdeconfigbackend.h"
#include "ksimpleconfig.h"
diff --git a/tdecore/kstddirs.h b/tdecore/kstddirs.h
deleted file mode 100644
index a009a750d..000000000
--- a/tdecore/kstddirs.h
+++ /dev/null
@@ -1,6 +0,0 @@
-// kstddirs.h is the old name, use #include <kstandarddirs.h> from now on
-#ifdef KDE_NO_COMPAT
-#error kstddirs.h is the old name, use #include <kstandarddirs.h> from now on
-#else
-#include <kstandarddirs.h>
-#endif
diff --git a/tdecore/ktempdir.cpp b/tdecore/ktempdir.cpp
index a11e582f2..db954010e 100644
--- a/tdecore/ktempdir.cpp
+++ b/tdecore/ktempdir.cpp
@@ -51,7 +51,7 @@
#include "tdeapplication.h"
#include "kinstance.h"
#include "ktempdir.h"
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
#include "tdeprocess.h"
#include <kdebug.h>
#include "kde_file.h"
diff --git a/tdecore/network/kresolverstandardworkers.cpp b/tdecore/network/kresolverstandardworkers.cpp
index c10c64e97..ed083f541 100644
--- a/tdecore/network/kresolverstandardworkers.cpp
+++ b/tdecore/network/kresolverstandardworkers.cpp
@@ -45,7 +45,7 @@
#include "kdebug.h"
#include "tdeglobal.h"
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
#include "tdeapplication.h"
#include "kresolver.h"
diff --git a/tdecore/tde-config.cpp.cmake b/tdecore/tde-config.cpp.cmake
index 14553d2e7..7c1eebbd2 100644
--- a/tdecore/tde-config.cpp.cmake
+++ b/tdecore/tde-config.cpp.cmake
@@ -1,7 +1,7 @@
#include <tdecmdlineargs.h>
#include <tdelocale.h>
#include <kinstance.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdeglobal.h>
#include <tdeglobalsettings.h>
#include <stdio.h>
diff --git a/tdecore/tde-config.cpp.in b/tdecore/tde-config.cpp.in
index 86394d75d..2373a7a13 100644
--- a/tdecore/tde-config.cpp.in
+++ b/tdecore/tde-config.cpp.in
@@ -1,7 +1,7 @@
#include <tdecmdlineargs.h>
#include <tdelocale.h>
#include <kinstance.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdeglobal.h>
#include <tdeglobalsettings.h>
#include <stdio.h>
diff --git a/tdecore/tdeaboutdata.cpp b/tdecore/tdeaboutdata.cpp
index 48f41645d..318a38d50 100644
--- a/tdecore/tdeaboutdata.cpp
+++ b/tdecore/tdeaboutdata.cpp
@@ -21,7 +21,7 @@
#include <tdeaboutdata.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tqfile.h>
#include <tqtextstream.h>
diff --git a/tdecore/tdeapplication.cpp b/tdecore/tdeapplication.cpp
index 2cdc4b3a4..fb11f90d4 100644
--- a/tdecore/tdeapplication.cpp
+++ b/tdecore/tdeapplication.cpp
@@ -69,7 +69,7 @@
#endif
#include <tdeglobal.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <kdebug.h>
#include <tdelocale.h>
#include <tdestyle.h>
@@ -93,7 +93,7 @@
#include <kprotocolinfo.h>
#include <kkeynative.h>
#include <kmdcodec.h>
-#include <kglobalaccel.h>
+#include <tdeglobalaccel.h>
#if defined TQ_WS_X11
#include <tdestartupinfo.h>
diff --git a/tdecore/tdeconfig.cpp b/tdecore/tdeconfig.cpp
index 68307dc85..4f67d5681 100644
--- a/tdecore/tdeconfig.cpp
+++ b/tdecore/tdeconfig.cpp
@@ -37,7 +37,7 @@
#include "tdeconfig.h"
#include "tdeglobal.h"
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
#include "kstaticdeleter.h"
#include <tqtimer.h>
diff --git a/tdecore/tdeconfig_compiler/example/autoexample.cpp b/tdecore/tdeconfig_compiler/example/autoexample.cpp
index 6085fa6eb..ee1233e54 100644
--- a/tdecore/tdeconfig_compiler/example/autoexample.cpp
+++ b/tdecore/tdeconfig_compiler/example/autoexample.cpp
@@ -31,7 +31,7 @@
#include <tdecmdlineargs.h>
#include <tdeglobal.h>
#include <tdeconfig.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdeconfigdialog.h>
#include <tqlabel.h>
diff --git a/tdecore/tdeconfig_compiler/example/example.cpp b/tdecore/tdeconfig_compiler/example/example.cpp
index 157570d98..662e60d0f 100644
--- a/tdecore/tdeconfig_compiler/example/example.cpp
+++ b/tdecore/tdeconfig_compiler/example/example.cpp
@@ -28,7 +28,7 @@
#include <tdecmdlineargs.h>
#include <tdeglobal.h>
#include <tdeconfig.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
int main( int argc, char **argv )
{
diff --git a/tdecore/tdeconfig_compiler/tdeconfig_compiler.cpp b/tdecore/tdeconfig_compiler/tdeconfig_compiler.cpp
index b950a3288..ec4b16b96 100644
--- a/tdecore/tdeconfig_compiler/tdeconfig_compiler.cpp
+++ b/tdecore/tdeconfig_compiler/tdeconfig_compiler.cpp
@@ -34,7 +34,7 @@
#include <tdeglobal.h>
#include <tdeconfig.h>
#include <ksimpleconfig.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <iostream>
diff --git a/tdecore/tdeconfigbackend.cpp b/tdecore/tdeconfigbackend.cpp
index 43dc6eb0a..707f4fe69 100644
--- a/tdecore/tdeconfigbackend.cpp
+++ b/tdecore/tdeconfigbackend.cpp
@@ -45,7 +45,7 @@
#include <tdeglobal.h>
#include <tdeprocess.h>
#include <tdelocale.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <ksavefile.h>
#include <kurl.h>
#include <kde_file.h>
diff --git a/tdecore/tdeconfigbase.cpp b/tdecore/tdeconfigbase.cpp
index 39e491279..3f44fbc7e 100644
--- a/tdecore/tdeconfigbase.cpp
+++ b/tdecore/tdeconfigbase.cpp
@@ -35,7 +35,7 @@
#include "tdeconfigbase.h"
#include "tdeconfigbackend.h"
#include "kdebug.h"
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
#include "kstringhandler.h"
class TDEConfigBase::TDEConfigBasePrivate
diff --git a/tdecore/tdeconfigskeleton.cpp b/tdecore/tdeconfigskeleton.cpp
index 03dac6156..dafe485fc 100644
--- a/tdecore/tdeconfigskeleton.cpp
+++ b/tdecore/tdeconfigskeleton.cpp
@@ -23,7 +23,7 @@
#include <tqvariant.h>
#include <tdeconfig.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdeglobal.h>
#include <tdeglobalsettings.h>
#include <kdebug.h>
diff --git a/tdecore/tdeglobal.cpp b/tdecore/tdeglobal.cpp
index aeac6f744..f00a8467c 100644
--- a/tdecore/tdeglobal.cpp
+++ b/tdecore/tdeglobal.cpp
@@ -38,7 +38,7 @@
#include <tdehardwaredevices.h>
#include <tdenetworkconnections.h>
#endif
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <kinstance.h>
#include "kstaticdeleter.h"
diff --git a/tdecore/kglobalaccel.cpp b/tdecore/tdeglobalaccel.cpp
index 5da0093a2..dd2a93b6f 100644
--- a/tdecore/kglobalaccel.cpp
+++ b/tdecore/tdeglobalaccel.cpp
@@ -17,15 +17,15 @@
Boston, MA 02110-1301, USA.
*/
-#include "kglobalaccel.h"
+#include "tdeglobalaccel.h"
#ifdef TQ_WS_X11
-#include "kglobalaccel_x11.h"
+#include "tdeglobalaccel_x11.h"
#elif defined(TQ_WS_WIN)
-#include "kglobalaccel_win.h"
+#include "tdeglobalaccel_win.h"
#elif defined(TQ_WS_MACX)
-#include "kglobalaccel_mac.h"
+#include "tdeglobalaccel_mac.h"
#else
-#include "kglobalaccel_emb.h"
+#include "tdeglobalaccel_emb.h"
#endif
#include <tqstring.h>
@@ -136,4 +136,4 @@ bool TDEGlobalAccel::useFourModifierKeys()
void TDEGlobalAccel::virtual_hook( int, void* )
{ /*BASE::virtual_hook( id, data );*/ }
-#include "kglobalaccel.moc"
+#include "tdeglobalaccel.moc"
diff --git a/tdecore/kglobalaccel.h b/tdecore/tdeglobalaccel.h
index 22dedd513..be34a3cdd 100644
--- a/tdecore/kglobalaccel.h
+++ b/tdecore/tdeglobalaccel.h
@@ -17,8 +17,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef _KGLOBALACCEL_H_
-#define _KGLOBALACCEL_H_
+#ifndef _TDEGLOBALACCEL_H_
+#define _TDEGLOBALACCEL_H_
#include <tqobject.h>
#include <tdeshortcut.h>
@@ -236,4 +236,4 @@ private:
class TDEGlobalAccelPrivate* d;
};
-#endif // _KGLOBALACCEL_H_
+#endif // _TDEGLOBALACCEL_H_
diff --git a/tdecore/kglobalaccel_emb.h b/tdecore/tdeglobalaccel_emb.h
index 5e5145d66..2fd16bd44 100644
--- a/tdecore/kglobalaccel_emb.h
+++ b/tdecore/tdeglobalaccel_emb.h
@@ -1,5 +1,5 @@
-#ifndef _KGLOBALACCEL_EMB_H
-#define _KGLOBALACCEL_EMB_H
+#ifndef _TDEGLOBALACCEL_EMB_H
+#define _TDEGLOBALACCEL_EMB_H
#include "tdeaccelbase.h"
#include "tdeshortcut.h"
@@ -15,4 +15,4 @@ public:
virtual bool disconnectKey( TDEAccelAction&, KKeySequence );
};
-#endif // _KGLOBALACCEL_EMB_H
+#endif // _TDEGLOBALACCEL_EMB_H
diff --git a/tdecore/kglobalaccel_mac.h b/tdecore/tdeglobalaccel_mac.h
index b2803b0c0..c21533916 100644
--- a/tdecore/kglobalaccel_mac.h
+++ b/tdecore/tdeglobalaccel_mac.h
@@ -1,5 +1,5 @@
-#ifndef _KGLOBALACCEL_MAC_H
-#define _KGLOBALACCEL_MAC_H
+#ifndef _TDEGLOBALACCEL_MAC_H
+#define _TDEGLOBALACCEL_MAC_H
#include <tqwidget.h>
@@ -28,4 +28,4 @@ public:
{ return false; }
};
-#endif // _KGLOBALACCEL_EMB_H
+#endif // _TDEGLOBALACCEL_MAC_H
diff --git a/tdecore/kglobalaccel_win.cpp b/tdecore/tdeglobalaccel_win.cpp
index a222d0242..faf3708f4 100644
--- a/tdecore/kglobalaccel_win.cpp
+++ b/tdecore/tdeglobalaccel_win.cpp
@@ -22,8 +22,8 @@
#include <tqwindowdefs.h>
#ifdef TQ_WS_WIN
-#include "kglobalaccel_win.h"
-#include "kglobalaccel.h"
+#include "tdeglobalaccel_win.h"
+#include "tdeglobalaccel.h"
#include "kkeyserver_x11.h"
#include <tqpopupmenu.h>
@@ -340,6 +340,6 @@ void TDEGlobalAccelPrivate::slotActivated( int iAction )
activate( pAction, KKeySequence() );
}
-#include "kglobalaccel_win.moc"
+#include "tdeglobalaccel_win.moc"
#endif // !TQ_WS_WIN
diff --git a/tdecore/kglobalaccel_win.h b/tdecore/tdeglobalaccel_win.h
index 45943b071..ec224a0f7 100644
--- a/tdecore/kglobalaccel_win.h
+++ b/tdecore/tdeglobalaccel_win.h
@@ -17,8 +17,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef _KGLOBALACCEL_WIN_H
-#define _KGLOBALACCEL_WIN_H
+#ifndef _TDEGLOBALACCEL_WIN_H
+#define _TDEGLOBALACCEL_WIN_H
#include <tqmap.h>
#include <tqwidget.h>
@@ -74,4 +74,4 @@ class TDEGlobalAccelPrivate : public TQWidget, public TDEAccelBase
bool m_blockingDisabled;
};
-#endif // _KGLOBALACCEL_WIN_H
+#endif // _TDEGLOBALACCEL_WIN_H
diff --git a/tdecore/kglobalaccel_x11.cpp b/tdecore/tdeglobalaccel_x11.cpp
index a518c58c8..2bf6e0d3e 100644
--- a/tdecore/kglobalaccel_x11.cpp
+++ b/tdecore/tdeglobalaccel_x11.cpp
@@ -22,8 +22,8 @@
#include <tqwindowdefs.h>
#ifdef TQ_WS_X11
-#include "kglobalaccel_x11.h"
-#include "kglobalaccel.h"
+#include "tdeglobalaccel_x11.h"
+#include "tdeglobalaccel.h"
#include "kkeyserver_x11.h"
#include <tqpopupmenu.h>
@@ -446,6 +446,6 @@ void TDEGlobalAccelPrivate::slotActivated( int iAction )
activate( pAction, KKeySequence() );
}
-#include "kglobalaccel_x11.moc"
+#include "tdeglobalaccel_x11.moc"
#endif // !TQ_WS_X11
diff --git a/tdecore/kglobalaccel_x11.h b/tdecore/tdeglobalaccel_x11.h
index 1502d89cb..2162299ee 100644
--- a/tdecore/kglobalaccel_x11.h
+++ b/tdecore/tdeglobalaccel_x11.h
@@ -17,8 +17,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef _KGLOBALACCEL_X11_H
-#define _KGLOBALACCEL_X11_H
+#ifndef _TDEGLOBALACCEL_X11_H
+#define _TDEGLOBALACCEL_X11_H
#include <tqmap.h>
#include <tqwidget.h>
@@ -107,4 +107,4 @@ class TDEGlobalAccelPrivate : public TQWidget, public TDEAccelBase
bool m_suspended;
};
-#endif // _KGLOBALACCEL_X11_H
+#endif // _TDEGLOBALACCEL_X11_H
diff --git a/tdecore/tdeglobalsettings.cpp b/tdecore/tdeglobalsettings.cpp
index 8540a4435..526970e1c 100644
--- a/tdecore/tdeglobalsettings.cpp
+++ b/tdecore/tdeglobalsettings.cpp
@@ -42,7 +42,7 @@ static TQRgb qt_colorref2qrgb(COLORREF col)
#include <kdebug.h>
#include <tdeglobal.h>
#include <tdeshortcut.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <kcharsets.h>
#include <tdeaccel.h>
#include <tdelocale.h>
diff --git a/tdecore/tdehw/networkbackends/network-manager/network-manager.cpp b/tdecore/tdehw/networkbackends/network-manager/network-manager.cpp
index 754fd31b8..f41f5cbc8 100644
--- a/tdecore/tdehw/networkbackends/network-manager/network-manager.cpp
+++ b/tdecore/tdehw/networkbackends/network-manager/network-manager.cpp
@@ -1922,7 +1922,7 @@ void TDENetworkConnectionManager_BackendNM::loadConnectionInformation() {
}
#ifdef DEBUG_NETWORK_MANAGER_COMMUNICATIONS
- printf("[network-manager comm debug] %s\n", (*it).data()); fflush(stdout);
+ printf("[network-manager comm debug] %s\n", (*it).local8Bit().data()); fflush(stdout);
#endif // DEBUG_NETWORK_MANAGER_COMMUNICATIONS
// Obtain connection settings from the path specified
@@ -4941,34 +4941,39 @@ TDENetworkVPNTypeList TDENetworkConnectionManager_BackendNM::availableVPNTypes()
TDENetworkVPNTypeList ret;
// Query NetworkManager to verify plugin availability before claiming support for a VPN type
- TQDir serviceDir(NM_PLUGIN_SERVICE_DIR, TQString(), TQDir::Name|TQDir::IgnoreCase, TQDir::Files);
- TQStringList services = serviceDir.entryList ().grep (".name", true);
-
- if (services.count () > 0) {
- // read in all available Services
- for (TQStringList::Iterator i = services.begin (); i != services.end (); ++i) {
- TQString service = NM_PLUGIN_SERVICE_DIR + TQString ("/") + *i;
- TDEConfig* tdeconfig = new TDEConfig (service, true, true, "config");
- tdeconfig->setGroup ("VPN Connection");
-
- TQString serviceName = tdeconfig->readEntry("name", TQString());
- serviceName = serviceName.lower();
-
- if (serviceName == "openvpn") {
- ret.append(TDENetworkVPNType::OpenVPN);
- }
- if (serviceName == "pptp") {
- ret.append(TDENetworkVPNType::PPTP);
- }
- if (serviceName == "strongswan") {
- ret.append(TDENetworkVPNType::StrongSwan);
- }
- if (serviceName == "vpnc") {
- ret.append(TDENetworkVPNType::VPNC);
- }
+ // Look in the LIB directory first, since that seems to be where plugins are stored nowadays.
+ TQDir libServiceDir(NM_PLUGIN_SERVICE_DIR_LIB, "*.name", TQDir::Name | TQDir::IgnoreCase, TQDir::Files);
+ TQDir etcServiceDir(NM_PLUGIN_SERVICE_DIR_ETC, "*.name", TQDir::Name | TQDir::IgnoreCase, TQDir::Files);
+ TQStringList services = libServiceDir.entryList() + etcServiceDir.entryList();
+ size_t libEntryCount = libServiceDir.count();
+
+ // Read in all services.
+ for (size_t i = 0; i < services.count(); ++i)
+ {
+ TQString fileName = TQString("%1/").arg(i < libEntryCount ? NM_PLUGIN_SERVICE_DIR_LIB : NM_PLUGIN_SERVICE_DIR_ETC) + services[i];
+ TDEConfig *config = new TDEConfig(fileName, true, true, "config");
+ config->setGroup("VPN Connection");
- delete tdeconfig;
+ TQString serviceName = config->readEntry("name", TQString(""));
+ serviceName = serviceName.lower();
+ if (serviceName == "openvpn")
+ {
+ ret.append(TDENetworkVPNType::OpenVPN);
+ }
+ if (serviceName == "pptp")
+ {
+ ret.append(TDENetworkVPNType::PPTP);
+ }
+ if (serviceName == "strongswan")
+ {
+ ret.append(TDENetworkVPNType::StrongSwan);
+ }
+ if (serviceName == "vpnc")
+ {
+ ret.append(TDENetworkVPNType::VPNC);
}
+
+ delete config;
}
return ret;
diff --git a/tdecore/tdehw/networkbackends/network-manager/network-manager.h b/tdecore/tdehw/networkbackends/network-manager/network-manager.h
index 8af99e846..241e83706 100644
--- a/tdecore/tdehw/networkbackends/network-manager/network-manager.h
+++ b/tdecore/tdehw/networkbackends/network-manager/network-manager.h
@@ -18,6 +18,7 @@
#ifndef _TDENETWORKBACKEND_NETWORKMANAGER_H
#define _TDENETWORKBACKEND_NETWORKMANAGER_H
+#include "config.h"
#include "tdenetworkconnections.h"
//====================================================================================================
@@ -142,7 +143,8 @@
#define NM_802_11_DEVICE_CAP_WPA 0x10
#define NM_802_11_DEVICE_CAP_RSN 0x20
//====================================================================================================
-#define NM_PLUGIN_SERVICE_DIR "/etc/NetworkManager/VPN"
+#define NM_PLUGIN_SERVICE_DIR_ETC "/etc/NetworkManager/VPN" // old plugin location
+#define NM_PLUGIN_SERVICE_DIR_LIB NM_VPN_SERVICE_DIR // new plugin location
//====================================================================================================
//====================================================================================================
diff --git a/tdecore/tdehw/tdehardwaredevices.cpp b/tdecore/tdehw/tdehardwaredevices.cpp
index 59db6d0ae..a9e9be9da 100644
--- a/tdecore/tdehw/tdehardwaredevices.cpp
+++ b/tdecore/tdehw/tdehardwaredevices.cpp
@@ -25,7 +25,7 @@
#include <tqstringlist.h>
#include <tdeconfig.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdeglobal.h>
#include <tdelocale.h>
diff --git a/tdecore/tdehw/tderootsystemdevice.cpp b/tdecore/tdehw/tderootsystemdevice.cpp
index cb9016062..65194374d 100644
--- a/tdecore/tdehw/tderootsystemdevice.cpp
+++ b/tdecore/tdehw/tderootsystemdevice.cpp
@@ -28,7 +28,7 @@
#include "tdeglobal.h"
#include "tdeconfig.h"
#include "tdeapplication.h"
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
#include "config.h"
diff --git a/tdecore/tdehw/tdestoragedevice.cpp b/tdecore/tdehw/tdestoragedevice.cpp
index df5f90ab7..4ef9e71eb 100644
--- a/tdecore/tdehw/tdestoragedevice.cpp
+++ b/tdecore/tdehw/tdestoragedevice.cpp
@@ -34,7 +34,7 @@
#include "tdeglobal.h"
#include "kiconloader.h"
#include "tdetempfile.h"
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
#include "tdehardwaredevices.h"
#include "disksHelper.h"
diff --git a/tdecore/tdelocale.cpp b/tdecore/tdelocale.cpp
index 3c6dc0cc8..07f3eea21 100644
--- a/tdecore/tdelocale.cpp
+++ b/tdecore/tdelocale.cpp
@@ -33,7 +33,7 @@
#include "kcatalogue.h"
#include "tdeglobal.h"
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
#include "ksimpleconfig.h"
#include "kinstance.h"
#include "tdeconfig.h"
diff --git a/tdecore/tdeprocess.cpp b/tdecore/tdeprocess.cpp
index e60f30118..185bd5a6f 100644
--- a/tdecore/tdeprocess.cpp
+++ b/tdecore/tdeprocess.cpp
@@ -72,7 +72,7 @@
#include <tqapplication.h>
#include <kdebug.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <kuser.h>
diff --git a/tdecore/tdeshortcutlist.cpp b/tdecore/tdeshortcutlist.cpp
index ffacd001c..cc9961199 100644
--- a/tdecore/tdeshortcutlist.cpp
+++ b/tdecore/tdeshortcutlist.cpp
@@ -6,7 +6,7 @@
#include <tdeconfig.h>
#include <kdebug.h>
#include <tdeglobal.h>
-#include <kglobalaccel.h>
+#include <tdeglobalaccel.h>
#include <kinstance.h>
#include <tdeshortcut.h>
#include "tdeshortcutlist.h"
diff --git a/tdecore/tdesycoca.cpp b/tdecore/tdesycoca.cpp
index fff419532..80764faec 100644
--- a/tdecore/tdesycoca.cpp
+++ b/tdecore/tdesycoca.cpp
@@ -31,7 +31,7 @@
#include <tdeglobal.h>
#include <kdebug.h>
#include <tdeprocess.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <assert.h>
#include <stdlib.h>
diff --git a/tdecore/tdetempfile.cpp b/tdecore/tdetempfile.cpp
index 805d315a1..d498f1258 100644
--- a/tdecore/tdetempfile.cpp
+++ b/tdecore/tdetempfile.cpp
@@ -52,7 +52,7 @@
#include "tdeapplication.h"
#include "kinstance.h"
#include "tdetempfile.h"
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
#include "kde_file.h"
#include "kdebug.h"
diff --git a/tdecore/tdeuniqueapplication.cpp b/tdecore/tdeuniqueapplication.cpp
index 1614ac3d7..85904a622 100644
--- a/tdecore/tdeuniqueapplication.cpp
+++ b/tdecore/tdeuniqueapplication.cpp
@@ -35,7 +35,7 @@
#include <dcopclient.h>
#include <tdecmdlineargs.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdeaboutdata.h>
#if defined TQ_WS_X11
diff --git a/tdecore/tests/CMakeLists.txt b/tdecore/tests/CMakeLists.txt
index e79dbfdeb..19b1fa9d3 100644
--- a/tdecore/tests/CMakeLists.txt
+++ b/tdecore/tests/CMakeLists.txt
@@ -30,23 +30,41 @@ tde_add_library( tdeconfigtest SHARED AUTOMOC
EXCLUDE_FROM_ALL
)
-set( CHECKS
- tdeconfigtestgui klocaletest tdeprocesstest ksimpleconfigtest kstddirstest
- tdeuniqueapptest ktempfiletest krandomsequencetest kdebugtest
- ksocktest kstringhandlertest kcmdlineargstest tdeapptest kmemtest
- dcopkonqtest kipctest cplusplustest kiconloadertest kresolvertest
- kmdcodectest knotifytest ksortablevaluelisttest krfcdatetest testqtargs
- tdeprociotest kcharsetstest kcalendartest kmacroexpandertest kshelltest
- kxerrorhandlertest startserviceby kglobaltest ktimezonestest
+set( AUTOMATED_CHECKS
+ kcharsetstest kglobaltest kmacroexpandertest krfcdatetest
+ kstringhandlertest kurltest tdestdacceltest
+
+ # cplusplustest # -- skip (doesn't error on errors)
+ # ksimpleconfigtest # -- skip (doesn't error on errors)
+ # ksortablevaluelist # -- skip (doesn't error on errors)
+ # ksocktest # -- skip due to DNS failure
)
+# Tests that require some graphical interaction / confirmation.
+set( MANUAL_CHECKS_GUI
+ kdebugtest klocaletest knotifytest kxerrorhandlertest
+ startserviceby tdeconfigtestgui tdeprocesstest testqtargs
+)
-foreach( _check ${CHECKS} )
- tde_add_check_executable( ${_check} AUTOMOC LINK tdeconfigtest-shared )
+# Tests that require some interaction using a terminal
+set( MANUAL_CHECKS_TUI
+ dcopkonqtest kcalendartest kcmdlineargstest kiconloadertest
+ kipctest kmemtest krandomsequencetest kresolvertest
+ kmdcodectest kshelltest ktempfiletest ktimezonestest
+ tdeapptest tdeprociotest tdestandarddirstest tdeuniqueapptest
+)
+
+foreach( _check ${AUTOMATED_CHECKS} )
+ tde_add_check_executable( ${_check} AUTOMOC LINK tdeconfigtest-shared TEST )
endforeach( )
-tde_add_check_executable( kurltest AUTOMOC LINK tdeconfigtest-shared TEST )
-tde_add_check_executable( tdestdacceltest AUTOMOC LINK tdeconfigtest-shared TEST )
+foreach( _check ${MANUAL_CHECKS_GUI})
+ tde_add_check_executable( ${_check} AUTOMOC LINK tdeconfigtest-shared )
+endforeach()
+
+foreach( _check ${MANUAL_CHECKS_TUI})
+ tde_add_check_executable( ${_check} AUTOMOC LINK tdeconfigtest-shared )
+endforeach()
tde_add_check_executable( kidlservertest AUTOMOC SOURCES KIDLTest.cpp KIDLTest.skel
LINK tdeconfigtest-shared )
diff --git a/tdecore/tests/Makefile.am b/tdecore/tests/Makefile.am
index cbf12cb2c..b7d4dc88e 100644
--- a/tdecore/tests/Makefile.am
+++ b/tdecore/tests/Makefile.am
@@ -22,7 +22,7 @@ INCLUDES = -I$(top_srcdir)/tdecore $(all_includes)
AM_LDFLAGS = $(QT_LDFLAGS) $(X_LDFLAGS) $(KDE_RPATH)
check_PROGRAMS = tdeconfigtestgui klocaletest tdeprocesstest ksimpleconfigtest \
- kstddirstest kurltest tdeuniqueapptest ktempfiletest krandomsequencetest \
+ tdestandarddirstest kurltest tdeuniqueapptest ktempfiletest krandomsequencetest \
kdebugtest ksocktest kstringhandlertest kcmdlineargstest tdeapptest \
kmemtest kidlservertest kidlclienttest dcopkonqtest kipctest \
cplusplustest kiconloadertest kresolvertest kmdcodectest knotifytest \
@@ -45,7 +45,7 @@ klocaletest_SOURCES = klocaletest.cpp
#kcatalogue_SOURCES = kcatalogue.cpp libintl.cpp
ksimpleconfigtest_SOURCES = ksimpleconfigtest.cpp
kurltest_SOURCES = kurltest.cpp
-kstddirstest_SOURCES = kstddirstest.cpp
+tdestandarddirstest_SOURCES = tdestandarddirstest.cpp
tdeprocesstest_SOURCES = tdeprocesstest.cpp
tdeuniqueapptest_SOURCES = tdeuniqueapptest.cpp
tdeapptest_SOURCES = tdeapptest.cpp
diff --git a/tdecore/tests/krfcdatetest.cpp b/tdecore/tests/krfcdatetest.cpp
index 94358a8f1..c67c5a4e2 100644
--- a/tdecore/tests/krfcdatetest.cpp
+++ b/tdecore/tests/krfcdatetest.cpp
@@ -59,6 +59,12 @@ int main(int argc, char *argv[])
a = KRFCDate::parseDateISO8601("1994-01-01");
check( "1994-01-01", a, b );
+ a = KRFCDate::parseDateISO8601("1994-01-01T12");
+ check("1994-01-01T12", a, b);
+
+ a = KRFCDate::parseDateISO8601("1994-01-01T12:00");
+ check("1994-01-01T12:00", a, b);
+
b = 0;
// pass RFC date to ISO parser
diff --git a/tdecore/tests/ktempfiletest.cpp b/tdecore/tests/ktempfiletest.cpp
index 019db0690..38960bf1a 100644
--- a/tdecore/tests/ktempfiletest.cpp
+++ b/tdecore/tests/ktempfiletest.cpp
@@ -18,7 +18,7 @@
#include "tdetempfile.h"
#include "tdeapplication.h"
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
#include <tqstring.h>
#include <unistd.h>
diff --git a/tdecore/tests/kstddirstest.cpp b/tdecore/tests/tdestandarddirstest.cpp
index ae6ea16bd..53d76a83c 100644
--- a/tdecore/tests/kstddirstest.cpp
+++ b/tdecore/tests/tdestandarddirstest.cpp
@@ -1,7 +1,7 @@
#include <tdeapplication.h>
#include <kdebug.h>
#include <kinstance.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdeconfig.h>
int main(int argc, char **argv)
diff --git a/tdecore/kstandarddirs.cpp b/tdecore/tdestandarddirs.cpp
index b7d41d136..89889367a 100644
--- a/tdecore/kstandarddirs.cpp
+++ b/tdecore/tdestandarddirs.cpp
@@ -1,4 +1,4 @@
-/* This file is part of the KDE libraries
+/* This file is part of the TDE libraries
Copyright (C) 1999 Sirtaj Singh Kang <[email protected]>
Copyright (C) 1999 Stephan Kulow <[email protected]>
Copyright (C) 1999 Waldo Bastian <[email protected]>
@@ -46,7 +46,7 @@
#include <tqstring.h>
#include <tqstringlist.h>
-#include "kstandarddirs.h"
+#include "tdestandarddirs.h"
#include "tdeconfig.h"
#include "kinstance.h"
#include "kshell.h"
@@ -74,7 +74,7 @@ public:
TQStringList xdgconf_prefixes;
};
// Singleton, with data shared by all kstandarddirs instances.
// Used in static methods like findExe()
class TDEStandardDirsSingleton
{
@@ -441,7 +441,7 @@ TQString TDEStandardDirs::findResourceDir( const char *type,
#ifndef NDEBUG
if(false && strcmp(type, "locale"))
- fprintf(stderr, "KStdDirs::findResDir(): can't find \"%s\" in type \"%s\".\n", filename.ascii(), type);
+ fprintf(stderr, "TDEStandardDirs::findResourceDir(): can't find \"%s\" in type \"%s\".\n", filename.ascii(), type);
#endif
return TQString::null;
@@ -74,7 +74,7 @@ public:
TQStringList xdgconf_prefixes;
};
-// Singleton, with data shared by all kstandarddirs instances.
+// Singleton, with data shared by all tdestandarddirs instances.
// Used in static methods like findExe()
class TDEStandardDirsSingleton
diff --git a/tdecore/kstandarddirs.h b/tdecore/tdestandarddirs.h
index e40f7617f..b221ecd41 100644
--- a/tdecore/kstandarddirs.h
+++ b/tdecore/tdestandarddirs.h
@@ -1,5 +1,5 @@
/*
- This file is part of the KDE libraries
+ This file is part of the TDE libraries
Copyright (C) 1999 Sirtaj Singh Kang <[email protected]>
Copyright (C) 1999 Stephan Kulow <[email protected]>
Copyright (C) 1999 Waldo Bastian <[email protected]>
@@ -20,8 +20,8 @@
Boston, MA 02110-1301, USA.
*/
-#ifndef SSK_KSTDDIRS_H
-#define SSK_KSTDDIRS_H
+#ifndef _TDESTANDARDDIRS_H
+#define _TDESTANDARDDIRS_H
#include <tqstring.h>
#include <tqdict.h>
@@ -32,7 +32,7 @@ class TDEConfig;
class TDEStandardDirsPrivate;
/**
* @short Site-independent access to standard KDE directories.
* @author Stephan Kulow <[email protected]> and Sirtaj Singh Kang <[email protected]>
*
* This is one of the most central classes in tdelibs as
@@ -46,9 +46,9 @@ class TDEStandardDirsPrivate;
* (e.g. icon) and a filename (e.g. khexdit.xpm). In an ideal world
* the application would make no assumption where this file is and
* leave it up to TDEStandardDirs::findResource("apps", "Home.desktop")
- * to apply this knowledge to return /opt/kde/share/applnk/Home.desktop
+ * to apply this knowledge to return /opt/trinity/share/applnk/Home.desktop
* or ::locate("data", "kgame/background.jpg") to return
- * /opt/kde/share/apps/kgame/background.jpg
+ * /opt/trinity/share/apps/kgame/background.jpg
*
* The main idea behind TDEStandardDirs is that there are several
* toplevel prefixes below which the files lie. One of these prefixes is
@@ -70,7 +70,7 @@ class TDEStandardDirsPrivate;
*
* @li apps - Applications menu (.desktop files).
* @li cache - Cached information (e.g. favicons, web-pages)
- * @li cgi - CGIs to run from kdehelp.
+ * @li cgi - CGIs to run from tdehelp.
* @li config - Configuration files.
* @li data - Where applications store data.
* @li exe - Executables in $prefix/bin. findExe() for a function that takes $PATH into account.
@@ -116,7 +116,7 @@ class TDEStandardDirsPrivate;
* used to search for resources first. If TDEHOME is not
* specified it defaults to "$HOME/.trinity"
* @li TDEROOTHOME: Like TDEHOME, but used for the root user.
- * If TDEROOTHOME is not set it defaults to the .kde directory in the
+ * If TDEROOTHOME is not set it defaults to the .trinity directory in the
* home directory of root, usually "/root/.trinity".
* Note that the setting of $HOME is ignored in this case.
*
@@ -140,7 +140,7 @@ public:
*
* @li When compiling tdelibs, the prefix is added to this.
* @li TDEDIRS or TDEDIR is taking into account
- * @li Additional dirs may be loaded from kdeglobals.
+ * @li Additional dirs may be loaded from tdeglobals.
*
* @param dir The directory to append relative paths to.
*/
@@ -169,7 +169,7 @@ public:
*
* You may add as many as you need, but it is advised that there
* is exactly one to make writing definite.
- * All basic types ( kde_default) are added by addKDEDefaults(),
+ * All basic types (kde_default) are added by addKDEDefaults(),
* but for those you can add more relative paths as well.
*
* The later a suffix is added, the higher its priority. Note, that the
@@ -214,7 +214,7 @@ public:
* to findResource("lib", "libtdecore.la"). TDEStandardDirs will
* then look into the subdir lib of all elements of all prefixes
* ($TDEDIRS) for a file libtdecore.la and return the path to
- * the first one it finds (e.g. /opt/kde/lib/libtdecore.la)
+ * the first one it finds (e.g. /opt/trinity/lib/libtdecore.la)
*
* @param type The type of the wanted resource
* @param filename A relative filename of the resource.
@@ -262,7 +262,7 @@ public:
* Tries to find all directories whose names consist of the
* specified type and a relative path. So would
* findDirs("apps", "Settings") return
- * @li /opt/kde/share/applnk/Settings/
+ * @li /opt/trinity/share/applnk/Settings/
* @li /home/joe/.trinity/share/applnk/Settings/
*
* Note that it appends / to the end of the directories,
@@ -288,7 +288,7 @@ public:
*
* findResourceDir("lib", "libtdecore.la") would return the
* path of the subdir libtdecore.la is found first in
- * (e.g. /opt/kde/lib/)
+ * (e.g. /opt/trinity/lib/)
*
* @param type The type of the wanted resource
* @param filename A relative filename of the resource.
@@ -409,7 +409,7 @@ public:
/**
* This function adds the defaults that are used by the current
- * KDE version.
+ * TDE version.
*
* It's a series of addResourceTypes()
* and addPrefix() calls.
@@ -446,7 +446,7 @@ public:
* This function will return a list of all the types that TDEStandardDirs
* supports.
*
* @return All types that KDE supports
*/
TQStringList allTypes() const;
@@ -501,7 +501,7 @@ public:
static bool makeDir(const TQString& dir, int mode = 0755);
/**
* This returns a default relative path for the standard KDE
* resource types. Below is a list of them so you get an idea
* of what this is all about.
*
@@ -554,13 +554,13 @@ public:
/**
* @internal
* Returns the default toplevel directory where KDE is installed.
*/
static TQString kfsstnd_defaultprefix();
/**
* @internal
* Returns the default bin directory in which KDE executables are stored.
*/
static TQString kfsstnd_defaultbindir();
@@ -649,12 +649,12 @@ public:
* @{
* On The Usage Of 'locate' and 'locateLocal'
*
* Typical KDE applications use resource files in one out of
* three ways:
*
* 1) A resource file is read but is never written. A system
* default is supplied but the user can override this
- * default in his local .kde directory:
+ * default in his local .trinity directory:
*
* \code
* // Code example
@@ -665,7 +665,7 @@ public:
* 2) A resource file is read and written. If the user has no
* local version of the file the system default is used.
* The resource file is always written to the users local
- * .kde directory.
+ * .trinity directory.
*
* \code
* // Code example
@@ -681,7 +681,7 @@ public:
* 3) A resource file is read and written. No system default
* is used if the user has no local version of the file.
* The resource file is always written to the users local
- * .kde directory.
+ * .trinity directory.
*
* \code
* // Code example
@@ -726,4 +726,4 @@ TDECORE_EXPORT TQString locateLocal( const char *type, const TQString& filename,
/*! @} */
-#endif // SSK_KSTDDIRS_H
+#endif // _TDESTANDARDDIRS_H
@@ -32,7 +32,7 @@ class TDEConfig;
class TDEStandardDirsPrivate;
/**
- * @short Site-independent access to standard KDE directories.
+ * @short Site-independent access to standard TDE directories.
* @author Stephan Kulow <[email protected]> and Sirtaj Singh Kang <[email protected]>
*
@@ -446,7 +446,7 @@ public:
* supports.
*
- * @return All types that KDE supports
+ * @return All types that TDE supports
*/
TQStringList allTypes() const;
@@ -501,7 +501,7 @@ public:
static bool makeDir(const TQString& dir, int mode = 0755);
/**
- * This returns a default relative path for the standard KDE
+ * This returns a default relative path for the standard TDE
* resource types. Below is a list of them so you get an idea
* of what this is all about.
@@ -554,13 +554,13 @@ public:
/**
* @internal
- * Returns the default toplevel directory where KDE is installed.
+ * Returns the default toplevel directory where TDE is installed.
*/
static TQString kfsstnd_defaultprefix();
@@ -554,13 +554,13 @@ public:
/**
* @internal
- * Returns the default bin directory in which KDE executables are stored.
+ * Returns the default bin directory in which TDE executables are stored.
*/
static TQString kfsstnd_defaultbindir();
@@ -649,12 +649,12 @@ public:
* On The Usage Of 'locate' and 'locateLocal'
*
- * Typical KDE applications use resource files in one out of
+ * Typical TDE applications use resource files in one out of
* three ways:
*